from logger.logging_functions import login, start_run, log, upload_file, finish_run

# import ldm_python_client_lib
# ldm = ldm_python_client_lib.logging_functions

# from ldm_python_client_lib.logging_functions import login, start_run, log, upload_file, finish_run


print ("abc")


# print ("ldm ", ldm)


def main():
    print("Starting main ... ")
    logged_in = login('a1@test.com', 'a1')
    if logged_in:
        print("Logged in successfully.")
    else:
        print("Login failed.")
        exit()

    start_run("5ff5d74b925b02e4de347a15",
                # "5fce614dd489a6fe90ec221b",
                "comment",
                "https://gitlab.com/sprogis/dl-framework/-/commit/dd97bb13d1b95409a4129d7bff90e5c5a64a98d0")
    

    log({"msg": "starting program execution"})
    
    log({"msg": "test msg 1"})

    # upload_file('./python_client_app/weights.txt',".chp")
    # upload_file('./python_client_app/python_logging_client.py', "code")
    # upload_file('./python_client_app/labels.txt',"labels")

    log({"msg": "finishing program execution"})
    
    finish_run()
    return

    


main()



from logging_functions import Logger
import os

def main():
    print("Starting main ... ")

    user_token = "pbkdf2:sha256:150000$nWdPlQAs$aabb00748878c7a14cf11cc52f8403a4c8f67cc5d01dfed72a909102efea2716"
    project_id = "601ce17e4b412c36f67a495e"


    # logger = Logger(user_token, project_id, "http://185.23.162.189:5000")

    # logger = Logger(user_token, None, "http://185.23.162.189:5000")

    logger = Logger(user_token, project_id)

    logger.add_project("Test upload2", "ImageClassificationa", description="This is description")


    # logger.start_run("comment", "https://gitlab.com/sprogis/dl-framework/-/commit/dd97bb13d1b95409a4129d7bff90e5c5a64a98d0")
    

    # logger.log({"msg": "starting program execution"})
    # logger.log({"msg": "test msg 1"})
    # logger.log({"msg": "finishing program execution"})


    # logger.upload_file('./captioning.py', "checkpoint")


    # results = [{"file": "image_0241.jpg", "silver": "buttercup is a flower",},
    #             {"file": "image_0242.jpg", "silver": "buttercup is a flower",},
    #             {"file": "image_0243.jpg", "silver": "bluebell is a flower",},
    #             {"file": "image_0244.jpg", "silver": "buttercup is a flower",},
    #             {"file": "image_0245.jpg", "silver": "bluebell is a flower",},
    #             {"file": "image_0246.jpg", "silver": "buttercup is a flower",},
    #             {"file": "image_0247.jpg", "silver": "bluebell is a flower",},
    #             {"file": "image_1126.jpg", "silver": "bluebell is a flower",},
    #         ]


    # logger.download_dataset("", "train")

    # logger.upload_dataset("../train", "Train")


    # results = [{"file": "Vid2.mp4", "silver": "abcded asdf asdf",},
    #             ]



    # logger.validate(results, "Train")


    # logger.finish_run()




    print ("Done")
    
    
main()
